\name{Matchit}

\alias{Matchit}

\title{Matchit: Matching Software for Causal Inference}

\description{

\emph{Matchit} enables parametric models for causal inference to work better by selecting
well-matched subsets of the original treated and control groups.  MatchIt implements the
suggestions of Ho, Imai, King, and Stuart (2004) for improving parametric statistical models by
preprocessing data with nonparametric matching methods.  MatchIt implements a wide range of
sophisticated matching methods, making it possible to greatly reduce the dependence of causal
inferences on hard-to-justify, but commonly made, statistical modeling assumptions.  The
software also easily fits into existing research practices since, after preprocessing with
MatchIt, researchers can use whatever parametric model they would have used without MatchIt, but
produce inferences with substantially more robustness and less sensitivity to modeling
assumptions.  Matched data sets created by MatchIt can be entered easily in Zelig
(\url{http://gking.harvard.edu/zelig}) for subsequent parametric analyses. Full documentation is
available online at \url{http://gking.harvard.edu/matchit}, and help for specific commands is
available through \code{help.matchit}.}

\details{
The matching is done using the \code{matchit(treat ~ X, ...)} command, where \code{treat} is the
vector of treatment assignments and \code{X} are the covariates to be used in the matching.  
There are a number of matching options, detailed below.  The full syntax is
\code{matchit(formula, data=NULL, discard=0, exact=FALSE, replace=FALSE, ratio=1, model="logit",
reestimate=FALSE, nearest=TRUE, m.order=2, caliper=0, calclosest=FALSE, mahvars=NULL,
subclass=0, subtype=1, interact=TRUE, \dots)} A summary of the results can be seen graphically
using \code{plot(matchitobject)}, or numerically using \code{summary(matchitobject)}.  
\code{print(matchitobject)} also prints out the output.  }

\usage{
matchit <- matchit(formula, data, model="logit", discard=0, reestimate=FALSE, nearest=TRUE,
                 replace=FALSE, m.order=2, ratio=1, caliper=0, calclosest=FALSE,
                 subclass=0, sub.by="treat", mahvars=NULL, exact=FALSE, counter=TRUE, ...)
}


\arguments{ 
\item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is
a binary treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and
\code{T}, \code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol
means "inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

\item{data}{(required).  Data frame containing the variables called in the \code{formula}.  The
dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}
	
\item{model}{Method used to estimate the propensity score.  May be "logit" (default), "probit",
"nnet", "GAM", or "cart".}
	
\item{discard}{Whether to discard units that fall outside some measure of support of the
distance score.  0 (default)=keep all units.  1=keep all units with common support.  2=discard
only control units outside the support of the distance measure of the treated units.  3=discard
only treated units outside the support of the distance measure of the control units.}
	
\item{reestimate}{Specifies whether to reestimate the propensity score model after discarding
units (default=FALSE).}
	
\item{nearest}{Whether to perform nearest-neighbor matching (default=TRUE).  }
\item{replace}{Whether to match with replacement (default=FALSE). } \item{m.order}{Order in
which to match treated units with control units.  2 (default)=from high to low, 3=from low to
high, 4=random order.} 

\item{ratio}{The number of control units to be matched to each treated
unit (default=1).} 

\item{caliper}{Standard deviations of the propensity score within which to
draw control units (default=0).} 

\item{calclosest}{If \code{caliper!=0}, whether to take the
nearest available match if no matches are available within \code{caliper} (default=FALSE).}
	
\item{subclass}{Either a scaler specifying the number of subclasses (default=0) or a vector of
probabilities to create quantiles based on \code{sub.by}.}
	
\item{sub.by}{If \code{subclass!=0}, by what criteria to subclassify.  "treat" (default) =by the
number of treated units, "control"=by the number of control units, "all"=by the total number of
units.}
	
\item{mahvars}{Variables on which to perform Mahalanobis matching within each caliper
(default=NULL).  Should be entered as a vector of names of variables in \code{data}.}
	
\item{exact}{"FALSE" (default)=no exact matching.  "TRUE"=exact matching on all variables in
\code{formula}.  A vector of variable names (that are in \code{data} to indicate separate
variables on which to exact match, in combination with matching on the propensity score.}
	
\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).}
	
\item{...}{Additional arguments to be passed to \code{matchit}, depending on the model to be
used.} 
}

\value{
  \item{call}{The original \code{matchit} call.}
  \item{formula}{Formula used to specify the propensity score.}
  \item{match.matrix}{n1 by ratio data frame where the rows correspond to treated units and the
columns store the names of the control units matched to each treated unit.  NA indicates that
treated unit was not matched.}
 
 \item{in.sample}{Vector of length n showing whether each unit was eligible for matching due to
common support restrictions with \code{discard}.}

  \item{matched}{Vector of length n showing whether each unit was matched.}

  \item{psweights}{Vector of length n giving the weight assigned to each unit in the matching
process.  Each weight is proportional to the number of times that unit was matched.}

  \item{psclass}{Subclass index in an ordinal scale from 1 to the number of subclasses.  
Unmatched units have subclass=0.}
  \item{q.cut}{Subclass cut points.}
  \item{assign.model}{Output of the assignment model.}
  \item{data}{The original data set, with \code{psclass}, \code{psweights}, and \code{pscore}
(propensity scores) added.}
  \item{treat}{The treatment indicator from \code{data}.}
  \item{covariates}{Covariates used in the right-hand side of the assignment model.}
}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\references{Daniel Ho, Kosuke Imai, Gary King, and Elizabeth Stuart (2004)
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{environment}









\eof
\name{diagnose}

\alias{diagnose}

\title{Diagnostics for matching procedure}

\description{\code{diagnose} is a sub-function of \code{matchit} which calculates summary
statistics for the matching, including the weight for each unit.}


\details{This is a sub-function of \code{matchit} which calculates summary statistics for the
matching procedure in \code{matchit}, calculating t-statistics for covariates as well as
weights for each unit.  This function is called directly by \code{matchit} and does not
generally need to be called directly by users; these details are included for advanced users. }

\usage{ diagnose <- diagnose(formula, match.matrix, pscore, in.sample, data, exact=FALSE,
		mahvars=NULL, subclass=0, psclass=NULL, nearest=TRUE, q.cut=NULL, counter=TRUE)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol means
"inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

  \item{match.matrix}{(required). n1 by ratio data frame where the rows correspond to treated
units and the columns store the names of the control units matched to each treated unit.  NA
indicates that treated unit was not matched. Generally created in \code{nearest}.}

  \item{pscore}{(required). Vector of estimated propensity scores.  Generally calculated in
\code{distance}.}

  \item{in.sample}{(required). Vector of length n showing whether each unit was eligible for
matching due to common support restrictions with \code{discard}.  Generally calculated in
\code{distance}.}

  \item{data}{(required).  Data frame containing the variables called in the \code{formula}.  
The dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}

	\item{exact}{"FALSE" (default)=no exact matching.  "TRUE"=exact matching on all
variables in \code{formula}.  A vector of variable names (that are in \code{data} to indicate
separate variables on which to exact match, in combination with matching on the propensity
score.}

	\item{mahvars}{Variables on which to perform Mahalanobis matching within each caliper
(default=NULL).  Should be entered as a vector of names of variables in \code{data}.}

	\item{subclass}{Either a scaler specifying the number of subclasses (default=0) or a
vector of probabilities to create quantiles based on \code{sub.by}.}

  \item{psclass}{Subclass index in an ordinal scale from 1 to the number of subclasses.  
Unmatched units have subclass=0.  Generally computed in \code{subclassify}.}

  \item{nearest}{Whether to perform nearest-neighbor matching (default=TRUE).  }
  \item{q.cut}{Subclass cut points.  Generally calculated in \code{subclassify}.}

   \item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).} }

\value{
  \item{psweights}{Vector of length n giving the weight assigned to each unit in the matching
process.  Each weight is proportional to the number of times that unit was matched.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}









\eof
\name{distance}

\alias{distance}

\title{Distance function: estimating propensity scores}

\description{ The distance function calculates the distance measure to be used in the matching,
usually the propensity score. It is a sub-function of \code{matchit}.}

\details{This is a sub-function of the \code{matchit} command, which calculates the distance
measure used in the matching, usually the propensity score.  This function is called directly by
\code{matchit} and does not generally need to be called directly by users; these details are
included for advanced users. }


\usage{
distance <- distance(formula, model="logit", data, discard=0, reestimate=FALSE, counter=TRUE, ...)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol means
"inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

  \item{data}{(required).  Data frame containing the variables called in the \code{formula}.  
The dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}

	\item{model}{Method used to estimate the propensity score.  May be "logit" (default),
"probit", "nnet", "GAM", or "cart".}

	\item{discard}{Whether to discard units that fall outside some measure of support of the
distance score.  0 (default)=keep all units.  1=keep all units with common support.  2=discard
only control units outside the support of the distance measure of the treated units.  3=discard
only treated units outside the support of the distance measure of the control units.}

	\item{reestimate}{Specifies whether to reestimate the propensity score model after
discarding units (default=FALSE).}

	\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).}

	\item{...}{Additional arguments to be passed to \code{distance}, depending on the model
to be used.} }

\value{
  \item{in.sample}{Vector of length n showing whether each unit was eligible for matching due to
common support restrictions with \code{discard}.}
  \item{pscore}{Vector of estimated propensity scores.}
  \item{treat}{The treatment indicator from \code{data}.}
  \item{covariates}{Covariates used in the right-hand side of the assignment model.}
  \item{assign.model}{Output of the assignment model.}
}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}


\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{internal}









\eof
\name{exactmatch}

\alias{exactmatch}

\title{Exact matching}

\description{\code{exactmatch} is a sub-function of \code{matchit} that does exact matching
on the set of covariates.}


\details{This sub-function is called automatically by the \code{matchit} command when
\code{exact=TRUE} is chosen, meaning exact matching on all covariates in the assignment model.  
It creates subclasses defined by the values of the covariates, where each subclass must contain
some treated and some control units.  Units with no exact matches in the other treatment group
are discarded.  This function is called directly by \code{matchit} and does not generally need
to be called directly by users; these details are included for advanced users. }

\usage{
exactmatch <- exactmatch(formula, data, counter=TRUE)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  Exact matching is done on the
variables on the right-hand side of \code{formula}.}

  \item{data}{(required).  Data frame containing the variables called in the \code{formula}.  
The dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}

	\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).} }

\value{
  \item{psclass}{Subclass index in an ordinal scale from 1 to the number of subclasses.  
Unmatched units have subclass=0.  With exact matching, these subclasses are defined by the
categories of the variables in \code{formula}.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}









\eof
\name{help.matchit}

\alias{help.matchit}

\title{HTML Help for Matchit Commands and Models}

\description{
  The \code{help.matchit} command launches html help for Matchit commands
  and supported models.  The full manual is available online at
  \url{http://gking.harvard.edu/matchit}.
  }

\usage{
help.matchit(object)
}

\arguments{
  \item{object}{a character string representing a Matchit command or model. 
    \code{help.matchit("command")} will take you to an index of Matchit
    commands and \code{help.matchit("model")} will take you to a list of
    models. }
  }

\seealso{The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

                                                                                                                                                             
\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{documentation}









\eof
\name{incomedata}
\docType{data}
\alias{incomedata}
\title{Simulated data to illustrate matching procedure for Matchit}

\description{
	This data set is a fake data set to be used to illustrate matching methods in the
Matchit library.  It has data on 200 individuals, 100 treated and 100 control, with treatment
assignemt, four covariates (income in 1974, income in 1975, male, and education), and one
outcome variable (income in 1978) observed. } 

\usage{data(incomedata)} 

\format{
	A data frame with 200 observations (rows) and six variables (columns).  The first
column, "treat", is the treatment assignment (1=treatment, 0=control).  The second column,
"income74", is income in 1974 (in U.S. dollars).  The third column, "income75", is income in
1975, also in U.S. dollars.  The fourth column, "male", is an indicator for male (1=male,
0=female). The fifth column, "educ", is the education level in years of schooling.  The sixth
column is the outcome variable, income in 1978 ("income78").  } 

\source{Simulated data.}
\keyword{datasets}

\eof
\name{lalonde}
\docType{data}
\alias{lalonde}
\title{Data from National Supported Work Demonstration and PSID, as analyzed by Dehejia and Wahba (1999).}

\description{ This is a subsample of the data from the treated group in the National Supported
Work Demonstration (NSW) and the comparison sample from the Current Population Survey (CPS).  
This data was previously analyzed extensively by Lalonde (1986) and Dehejia and Wahba (1999).  
The full dataset is available at \url{http://www.columbia.edu/~rd247/nswdata.html}. }

\usage{data(incomedata)}

\format{ A data frame with 313 observations (185 treated, 429 control).  There are 10 variables
measured for each individual.  "treat" is the treatment assignment (1=treated, 0=control).  
"age" is age in years.  "educ" is education in number of years of schooling.  "black" is an
indicator for African-American (1=African-American, 0=not).  "hispan" is an indicator for being
of Hispanic origin (1=Hispanic, 0=not).  "married" is an indicator for married (1=married, 0=not
married).  "nodegree" is an indicator for whether the individual has a high school degree (1=no
degree, 0=degree). "re74" is income in 1974, in U.S. dollars.  "re75" is income in 1975, in U.S.
dollars.  "re78" is income in 1978, in U.S. dollars. }

\references{
	Lalonde, R. (1986). Evaluating the econometric evaluations of training programs 
	with experimental data. {\it American Economic Review} 76: 604-620. \\

	Dehejia, R.H. and Wahba, S. (1999).  Causal Effects in Nonexperimental Studies: 
	Re-Evaluating the Evaluation  of Training Programs.  {\it Journal of the American 
	Statistical Association} 94: 1053-1062.
}
\source{\url{http://www.columbia.edu/~rd247/nswdata.html}}
\keyword{datasets}  

\eof
\name{match.data}

\alias{match.data}

\title{Output matched data sets}

\description{The code \code{match.data} creates output data sets from a \code{matchit}
matching algorithm.}

\usage{
match.data <- match.data(object, group="all")
}

\arguments{ 
\item{object}{(required).  Stored output from \code{matchit}.} 

\item{group}{Which units to output.  "all" (default) gives all matched units (treated and
control), "treat" gives just the matched treated units, and "control" gives just the matched
control units.} }

\value{ 
\item{Returns a subset of the original data set sent to \code{matchit}, with just the matched units.  The data set also contains the additional
variables \code{psclass}, \code{pscore}, and \code{psweights}.  The variable \code{psclass} gives the subclass index for each unit (if applicable).  
The variable \code{pscore} gives the propensity scores, and \code{psweights} gives the weights for each unit, generated in the matching procedure.  
See the \code{matchit} documentation for more details.} 
}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}

\eof
\name{matchdef}

\alias{matchdef}

\title{Nearest neighbor matching algorithm}

\description{ This is a sub-function of \code{matchit} which performs the nearest neighbor
matching; \code{matchdef} is called automatically by \code{matchit}. }


\details{The matching is done using nearest neighbor matching on the propensity score, estimated
in the sub-function \ref{distance}.  This function is called directly by \code{matchit} and
does not generally need to be called directly by users; these details are included for advanced
users. }

\usage{
matchdef <- matchdef(formula, in.sample, pscore, covariates, nearest=TRUE, replace=FALSE, 
		m.order=2, ratio=1, caliper=0, calclosest=FALSE, mahvars=NULL, exact=FALSE, 
		data=NULL, counter=TRUE)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol means
"inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

  \item{data}{Data frame containing the variables in \code{formula}.}
  \item{in.sample}{Vector of length n showing whether each unit was eligible for matching due to
common support restrictions with \code{discard}. Computed in \code{distance}.}

  \item{pscore}{Vector of propensity scores, calculated in \code{distance}.}

  \item{covariates}{Covariates from data frame used in matching process.  Output from
\code{distance}.}

	\item{nearest}{Whether to perform nearest-neighbor matching (default=TRUE).  }
	\item{replace}{Whether to match with replacement (default=FALSE). }
	\item{m.order}{Order in which to match treated units with control units.  2
(default)=from high to low, 3=from low to high, 4=random order.}
	\item{ratio}{The number of control units to be matched to each treated unit (default=1).}

	\item{caliper}{Standard deviations of the propensity score within which to draw control
units (default=0).}

	\item{calclosest}{If \code{caliper!=0}, whether to take the nearest available match if
no matches are available within \code{caliper} (default=FALSE).}

	\item{mahvars}{Variables on which to perform Mahalanobis matching within each caliper
(default=NULL).  Should be entered as a vector of names of variables in \code{data}.}

	\item{exact}{"FALSE" (default)=no exact matching.  "TRUE"=exact matching on all
variables in \code{formula}.  A vector of variable names (that are in \code{data}) to indicate
separate variables on which to exact match, in combination with matching on the propensity
score.}

	\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).} }

\value{
  \item{match.matrix}{n1 by ratio data frame where the rows correspond to treated units and the
columns store the names of the control units matched to each treated unit.  NA indicates that
treated unit was not matched.}

  \item{in.sample}{Vector of length n showing whether each unit was eligible for matching due to
common support restrictions with \code{discard}.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{internal}









\eof
\name{matchit}

\alias{matchit}
\alias{i}

\title{Matchit: Matching Software for Causal Inference}

\description{
\emph{Matchit} enables parametric models for causal inference to work better by selecting
well-matched subsets of the original treated and control groups.  MatchIt implements the
suggestions of Ho, Imai, King, and Stuart (2004) for improving parametric statistical models by
preprocessing data with nonparametric matching methods.  MatchIt implements a wide range of
sophisticated matching methods, making it possible to greatly reduce the dependence of causal
inferences on hard-to-justify, but commonly made, statistical modeling assumptions.  The
software also easily fits into existing research practices since, after preprocessing with
MatchIt, researchers can use whatever parametric model they would have used without MatchIt, but
produce inferences with substantially more robustness and less sensitivity to modeling
assumptions.  Matched data sets created by MatchIt can be entered easily in Zelig
(\url{http://gking.harvard.edu/zelig}) for subsequent parametric analyses. Full documentation is
available online at \url{http://gking.harvard.edu/matchit}, and help for specific commands is
available through \code{help.matchit}.}

\details{The matching is done using the \code{matchit(treat ~ X, ...)} command, where
\code{treat} is the vector of treatment assignments and \code{X} are the covariates to be used
in the matching.  There are a number of matching options, detailed below.  The full syntax is
\code{matchit(formula, data=NULL, discard=0, exact=FALSE, replace=FALSE, ratio=1, model="logit",
reestimate=FALSE, nearest=TRUE, m.order=2, caliper=0, calclosest=FALSE, mahvars=NULL,
subclass=0, subtype=1, interact=TRUE, \dots)} A summary of the results can be seen graphically
using \code{plot(matchitobject)}, or numerically using \code{summary(matchitobject)}.  
\code{print(matchitobject)} also prints out the output.  }

\usage{
matchit <- matchit(formula, data, model="logit", discard=0, reestimate=FALSE, nearest=TRUE,
                 replace=FALSE, m.order=2, ratio=1, caliper=0, calclosest=FALSE,
                 subclass=0, sub.by="treat", mahvars=NULL, exact=FALSE, counter=TRUE, ...)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol means
"inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

  \item{data}{(required).  Data frame containing the variables called in the \code{formula}.  
The dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}

	\item{model}{Method used to estimate the propensity score.  May be "logit" (default),
"probit", "nnet", "GAM", or "cart".}

	\item{discard}{Whether to discard units that fall outside some measure of support of the
distance score.  0 (default)=keep all units.  1=keep all units with common support.  2=discard
only control units outside the support of the distance measure of the treated units.  3=discard
only treated units outside the support of the distance measure of the control units.}

	\item{reestimate}{Specifies whether to reestimate the propensity score model after
discarding units (default=FALSE).}
	\item{nearest}{Whether to perform nearest-neighbor matching (default=TRUE).  }
	\item{replace}{Whether to match with replacement (default=FALSE). }
	\item{m.order}{Order in which to match treated units with control units.  2
(default)=from high to low, 3=from low to high, 4=random order.}

	\item{ratio}{The number of control units to be matched to each treated unit (default=1).}
	\item{caliper}{Standard deviations of the propensity score within which to draw control
units (default=0).}

	\item{calclosest}{If \code{caliper!=0}, whether to take the nearest available match if
no matches are available within \code{caliper} (default=FALSE).}

	\item{subclass}{Either a scaler specifying the number of subclasses (default=0) or a
vector of probabilities to create quantiles based on \code{sub.by}.}

	\item{sub.by}{If \code{subclass!=0}, by what criteria to subclassify.  "treat" (default)
=by the number of treated units, "control"=by the number of control units, "all"=by the total
number of units.}

	\item{mahvars}{Variables on which to perform Mahalanobis matching within each caliper
(default=NULL).  Should be entered as a vector of names of variables in \code{data}.}

	\item{exact}{"FALSE" (default)=no exact matching.  "TRUE"=exact matching on all
variables in \code{formula}.  A vector of variable names (that are in \code{data} to indicate
separate variables on which to exact match, in combination with matching on the propensity
score.}

	\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).}

	\item{...}{Additional arguments to be passed to \code{matchit}, depending on the model
to be used.} 
}

\value{
  \item{call}{The original \code{matchit} call.}
  \item{formula}{Formula used to specify the propensity score.}
  \item{match.matrix}{n1 by ratio data frame where the rows correspond to treated units and the
columns store the names of the control units matched to each treated unit.  NA indicates that
treated unit was not matched.}

  \item{in.sample}{Vector of length n showing whether each unit was eligible for matching due to
common support restrictions with \code{discard}.}

  \item{matched}{Vector of length n showing whether each unit was matched.}

  \item{psweights}{Vector of length n giving the weight assigned to each unit in the matching
process.  Each weight is proportional to the number of times that unit was matched.}

  \item{psclass}{Subclass index in an ordinal scale from 1 to the number of subclasses.  
Unmatched units have subclass=0.}
  \item{q.cut}{Subclass cut points.}
  \item{assign.model}{Output of the assignment model.}
  \item{data}{The original data set, with \code{psclass}, \code{psweights}, and \code{pscore}
(propensity scores) added.}
  \item{treat}{The treatment indicator from \code{data}.}
  \item{covariates}{Covariates used in the right-hand side of the assignment model.}
}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\references{Daniel Ho, Kosuke Imai, Gary King, and Elizabeth Stuart (2004)
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{environment}









\eof
\name{neyman}

\alias{neyman}
\alias{print.neyman}

\title{Estimating treatment effects: Neyman's method}

\description{Calculates basic estimate of treatment effect, using simple difference in means and
Neyman's estimate of the variance.}

\details{Calculates overall treatment effect estimate using matched samples generated by
\code{matchit}.  If subclasses were generated in the matching procedure, the estimate is a
weighted average over the subclasses, with subclass weights defined by the \code{sub.by} option
in the \code{matchit} call.  The standard deviation can also be estimated using the bootstrap
procedure, which is often used when matching done with replacement.  For more details on the
calculations, see the complete documentation (link below).  The \code{summary} command on a
\code{neyman} object will provide a test of significance of the outcome as well as sample sizes
of the matched treated and control groups, and subclass estimates if applicable.  }

\usage{
neyman <- neyman(Y, object, bootstrap=NULL, counter=TRUE)
}

\arguments{ 
\item{Y}{(required).  Outcome variable of interest, included in \code{data} from
\code{matchit} object.} 
\item{object}{(required).  Stored output from \code{matchit}.}
\item{bootstrap}{Use the bootstrap to estimate standard errors (default=FALSE).  Often used when
matching done with replacement.} 
\item{counter}{Counter indicating progress of the bootstrap
(default=TRUE, which shows the counter).} 
}

\value{ 
\item{Returns estimate of the effect of the treatment, as well as the standard deviation
of that estimate.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{htest}

\eof
\name{plot.matchit}

\alias{plot.matchit}

\title{Graphing Quantities of Interest}

\description{ The \code{matchit} method for the generic \code{plot}
  command generates default plots.}

\usage{
\method{plot}{matchit}(x, ...)
}

\arguments{
\item{x}{stored output from \code{\link{matchit}}.  }
\item{\dots}{Additional parameters passed to \code{plot.default}.
  Because \code{plot.matchit} primarily produces diagnostic plots, many
  of these parameters are hard-coded for convenience and
  presentation. }  
}

\value{ 
\item{\code{plot.matchit} allows the user to check the distribution of all covariates
in the assignment model, squares, and interactions, within all subclasses.  The graphs present
density estimate graphs of the propensity score of treated and control units in the full and
matched samples, jitter plots of the propensity score for treated and control units, density
estimate graphs of any covariates, and density estimate graphs of any covariates by subclass.}}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.
}
  
\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{hplot}

\eof
\name{print.matchit}

\alias{print.matchit}

\title{Printing Quantities of Interest}

\description{ The \code{matchit} method for the generic \code{print}
  command generates default output.
}

\usage{
\method{print}{matchit}(x,  digits = max(3, getOption("digits") - 3), ...)
}

\arguments{
\item{x}{stored output from \code{matchit}. } 
\item{digits}{Optionally specify the significant digits to be displayed.}
\item{\dots}{Additional parameters passed to \code{print.default}.}  
}

\value{ 
\item{Returns the original assignment model call, summary statistics of the propensity
score for the full and matched samples, summary statistics of the propensity score for each
subclass (if applicable), and sample sizes for the full and matched samples (full and by
subclass).} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}

\eof
\name{subclassify}

\alias{subclassify}

\title{Subclassify units}

\description{This is a sub-function of \code{matchit} which generates subclasses of units
given a propensity score.}

\details{This function creates subclasses of units based on their covariate values, usually
defined by the propensity score.  This function is called directly by \code{matchit} and does
not generally need to be called directly by users; these details are included for advanced
users. }

\usage{
subclassify <- subclassify(formula, data, in.sample, pscore, nearest=TRUE, match.matrix, 
	      	subclass=0, sub.by="treat", counter=TRUE)
}


\arguments{
  \item{formula}{(required).  Takes the form of \code{T ~ X1 + X2}, where \code{T} is a binary
treatment indicator and \code{X1} and \code{X2} are the pre-treatment covariates, and \code{T},
\code{X1}, and \code{X2} are contained in the same data frame.  The \code{+} symbol means
"inclusion" not "addition." You may also include interaction terms in the form if
\code{I(X1*X2)} or squared terms in the form of \code{I(X1^2)}.}

  \item{data}{(required).  Data frame containing the variables called in the \code{formula}.  
The dataframe should not include variables with the names \code{psclass}, \code{psweights}, or
\code{pscore}, as these are expressly reserved in the output dataframe for MatchIt.}

  \item{in.sample}{(required).  Vector of length n showing whether each unit was eligible for
matching due to common support restrictions with \code{discard}.  Generally created by
\code{distance}.}

  \item{pscore}{(required).  Vector of estimated propensity scores.  Generally created by
\code{distance}.}

	\item{nearest}{Whether to perform nearest-neighbor matching (default=TRUE).  }

  \item{match.matrix}{(required) n1 by ratio data frame where the rows correspond to treated
units and the columns store the names of the control units matched to each treated unit.  NA
indicates that treated unit was not matched.  Generally created by \code{matchdef}.}

	\item{subclass}{Either a scaler specifying the number of subclasses (default=0) or a
vector of probabilities to create quantiles based on \code{sub.by}.}

	\item{sub.by}{If \code{subclass!=0}, by what criteria to subclassify.  "treat" (default)
=by the number of treated units, "control"=by the number of control units, "all"=by the total
number of units.}

	\item{counter}{Whether to display counter indicating the progress of the matching
(default=TRUE).} }

\value{
  \item{psclass}{Subclass index in an ordinal scale from 1 to the number of subclasses.  
Unmatched units have subclass=0.}
  \item{q.cut}{Subclass cut points.}
}

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.  
}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{internal}









\eof
\name{summary.matchit}

\alias{summary.matchit}
\alias{print.summary.matchit}

\title{Summarizing Quantities of Interest}

\description{ The \code{matchit} method for the generic \code{summary}
  command generates default output.
}

\usage{
\method{summary}{matchit}(object, verbose=F, sig=2, ...)
}

\arguments{ 
\item{object}{stored output from \code{matchit}.} 

\item{sig}{Optionally specifies the size of the t-statistic for a covariate to be labeled
"problematic" (default=2).}

\item{verbose}{Option to show summary statistics in \code{sum.all} and \code{sum.matched} for
all covariates, their squares, and two-way interactions when \code{verbose=TRUE} and only the
covariates themselves when \code{verbose=FALSE} (default).}

\item{\dots}{Additional parameters
passed to \code{summary.default}.} }

\value{ 
\item{call}{The original assignment model call.} 

\item{sum.all}{Data frame containing summary statistics on all observations in the treated and
control groups (means, standard deviations, t-statistics and bias statistics for all
covariates).}

\item{sum.matched}{Data frame containing summary statistics on the matched observations in the
treated and control groups (means, standard deviations, t-statistics, bias statistics, and
whether bias was reduced by the matching).}

\item{Problematic}{Problematic covariates that remain imbalanced in the matched samples.  
Variables listed when the absolute value of the t-statistic in the matched sample exceeds
\code{sig}.}

\item{xn}{Sample sizes in the full and matched samples.}

\item{q.table}{Array that contains the same information as \code{sum.all} and \code{sum.matched}
for each subclass.} 

\item{qn}{Sample sizes in the full and matched samples, by subclass.}

\item{match.matrix}{From the \code{matchit} output.} 

\item{psclass}{From the \code{matchit} output.} 
\item{in.sample}{From the \code{matchit} output.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}

\eof
\name{summary.neyman}

\alias{summary.neyman}
\alias{print.summary.neyman}

\title{Summarizing the estimated treatment effects}

\description{Calculates basic estimate of treatment effect, using simple difference in means and
Neyman's estimate of the variance. Also provides test of significance and subclass estimates if
applicable.}

\details{Calculates overall treatment effect estimate using matched samples generated by
\code{matchit}.  Also gives test of significance of the estimated treatment effect, and subclass
estimates, if applicable.  If subclasses were generated in the matching procedure, an overall
estimate is also provided, which is a weighted average over the subclasses, with subclass
weights defined by the \code{sub.by} option in the \code{matchit} call.  The standard deviation
can also be estimated using the bootstrap procedure, which is often used when matching done with
replacement.  For more details on the calculations, see the complete documentation (link below).  
}

\usage{
\method{summary}{neyman}(object, ...)
}

\arguments{
\item{object}{(required).  Stored output from \code{neyman}. }
\item{...}{Further arguments passed to or from other methods.}
}

\value{ \item{Returns estimate of the effect of the treatment, as well as the standard deviation
of that estimate, a test of significance of the estimate, and subclass estimates if applicable.  
Also shows the sample sizes of the matched treated and control groups used to estimate the
treatment effect.} }

\seealso{Please use \code{help.matchit} to access the matchit reference
  manual.  The complete document is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>;  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}

\eof
